#region Using declarations
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using System.Windows.Media;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Gui;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Gui.SuperDom;
using NinjaTrader.Gui.Tools;
using NinjaTrader.Data;
using NinjaTrader.NinjaScript;
using NinjaTrader.Core.FloatingPoint;
using NinjaTrader.NinjaScript.DrawingTools;
#endregion

//This namespace holds Indicators in this folder and is required. Do not change it. 
namespace NinjaTrader.NinjaScript.Indicators
{
	/// <summary>
    /// Calculate Deviations from recent swing highs and lows to normalize price movement
	/// 
	/// Code Written by Tyler Moore
	/// www.FreeIndicators.Com
	/// 
	/// For modifications to this code or to have your own custom code written
	/// please visit www.MooreTechLLC.com	
    /// </summary>
	public class mtSwingOscillator : Indicator
	{
		#region Variables
        // User defined variables (add any user defined variables below)
		private MIN min;
		private MAX max;
		private double sh = 0, sl = 0;
		private int shBar = 0, slBar = 0;
        #endregion
		
		protected override void OnStateChange()
		{
			if (State == State.SetDefaults)
			{
				Description									= @"Calculate Deviations from recent swing highs and lows to normalize price movement from www.FreeIndicators.com";
				Name										= "mtSwingOscillator";
				Calculate									= Calculate.OnBarClose;
				IsOverlay									= false;
				DisplayInDataBox							= true;
				DrawOnPricePanel							= true;
				DrawHorizontalGridLines						= true;
				DrawVerticalGridLines						= true;
				PaintPriceMarkers							= true;
				ScaleJustification							= NinjaTrader.Gui.Chart.ScaleJustification.Right;
				//Disable this property if your indicator requires custom values that cumulate with each new market data event. 
				//See Help Guide for additional information.
				IsSuspendedWhileInactive					= true;
				
				Strength = 5;
				
				AddPlot(new Stroke(Brushes.Blue, 1),PlotStyle.Bar, "Osc");
			}
			else if (State == State.Configure)
			{
			}
			else if (State == State.DataLoaded)
			{
				min = MIN(Low,Strength);
				max = MAX(High,Strength);
			}
		}

		protected override void OnBarUpdate()
		{
			if (CurrentBar<1)
				return;
			
			if (High[0]>max[1])
			{
				sh=High[0];
				shBar=CurrentBar;
			}
			if (Low[0]<min[1])
			{
				sl=Low[0];
				slBar=CurrentBar;
			}
								
			if (shBar>slBar && slBar>0)			
			{
				PlotBrushes[0][0] = Brushes.Green;
				Osc[0] = (sh-sl);	
			}
			else if (slBar>shBar && shBar>0)
			{
				PlotBrushes[0][0] = Brushes.Red;
				Osc[0] = (sl-sh);	
			}
		}

		#region Properties
		[NinjaScriptProperty]
		[Range(1, int.MaxValue)]
		[Display(Name="Strength", Order=1, GroupName="Parameters")]
		public int Strength
		{ get; set; }

		[Browsable(false)]
		[XmlIgnore]
		public Series<double> Osc
		{
			get { return Values[0]; }
		}
		#endregion

	}
}

#region NinjaScript generated code. Neither change nor remove.

namespace NinjaTrader.NinjaScript.Indicators
{
	public partial class Indicator : NinjaTrader.Gui.NinjaScript.IndicatorRenderBase
	{
		private mtSwingOscillator[] cachemtSwingOscillator;
		public mtSwingOscillator mtSwingOscillator(int strength)
		{
			return mtSwingOscillator(Input, strength);
		}

		public mtSwingOscillator mtSwingOscillator(ISeries<double> input, int strength)
		{
			if (cachemtSwingOscillator != null)
				for (int idx = 0; idx < cachemtSwingOscillator.Length; idx++)
					if (cachemtSwingOscillator[idx] != null && cachemtSwingOscillator[idx].Strength == strength && cachemtSwingOscillator[idx].EqualsInput(input))
						return cachemtSwingOscillator[idx];
			return CacheIndicator<mtSwingOscillator>(new mtSwingOscillator(){ Strength = strength }, input, ref cachemtSwingOscillator);
		}
	}
}

namespace NinjaTrader.NinjaScript.MarketAnalyzerColumns
{
	public partial class MarketAnalyzerColumn : MarketAnalyzerColumnBase
	{
		public Indicators.mtSwingOscillator mtSwingOscillator(int strength)
		{
			return indicator.mtSwingOscillator(Input, strength);
		}

		public Indicators.mtSwingOscillator mtSwingOscillator(ISeries<double> input , int strength)
		{
			return indicator.mtSwingOscillator(input, strength);
		}
	}
}

namespace NinjaTrader.NinjaScript.Strategies
{
	public partial class Strategy : NinjaTrader.Gui.NinjaScript.StrategyRenderBase
	{
		public Indicators.mtSwingOscillator mtSwingOscillator(int strength)
		{
			return indicator.mtSwingOscillator(Input, strength);
		}

		public Indicators.mtSwingOscillator mtSwingOscillator(ISeries<double> input , int strength)
		{
			return indicator.mtSwingOscillator(input, strength);
		}
	}
}

#endregion
